@@ -1,6 +1,5 @@
 from collections.abc import Iterable
 
-import six
 import sqlalchemy as sa
 from sqlalchemy.ext.hybrid import hybrid_property
 from sqlalchemy.orm import attributes, class_mapper, ColumnProperty
@@ -10,6 +9,7 @@ from sqlalchemy.util import set_creation_order
 
 from .exceptions import ImproperlyConfigured
 from .functions import identity
+from .functions.orm import _get_class_registry
 
 
 class GenericAttributeImpl(attributes.ScalarAttributeImpl):
@@ -27,7 +27,7 @@ class GenericAttributeImpl(attributes.ScalarAttributeImpl):
         # Find class for discriminator.
         # TODO: Perhaps optimize with some sort of lookup?
         discriminator = self.get_state_discriminator(state)
-        target_class = state.class_._decl_class_registry.get(discriminator)
+        target_class = _get_class_registry(state.class_).get(discriminator)
 
         if target_class is None:
             # Unknown discriminator; return nothing.
@@ -35,7 +35,11 @@ class GenericAttributeImpl(attributes.ScalarAttributeImpl):
 
         id = self.get_state_id(state)
 
-        target = session.query(target_class).get(id)
+        try:
+            target = session.get(target_class, id)
+        except AttributeError:
+            # sqlalchemy 1.3
+            target = session.query(target_class).get(id)
 
         # Return found (or not found) target.
         return target
@@ -73,7 +77,7 @@ class GenericAttributeImpl(attributes.ScalarAttributeImpl):
             pk = mapper.identity_key_from_instance(initiator)[1]
 
             # Set the identifier and the discriminator.
-            discriminator = six.text_type(class_.__name__)
+            discriminator = class_.__name__
 
             for index, id in enumerate(self.parent_token.id):
                 dict_[id.key] = pk[index]
@@ -93,7 +97,7 @@ class GenericRelationshipProperty(MapperProperty):
     """
 
     def __init__(self, discriminator, id, doc=None):
-        super(GenericRelationshipProperty, self).__init__()
+        super().__init__()
         self._discriminator_col = discriminator
         self._id_cols = id
         self._id = None
@@ -109,14 +113,14 @@ class GenericRelationshipProperty(MapperProperty):
                 if key == attr_key:
                     return attr
         else:
-            for key, attr in self.parent.attrs.items():
+            for attr in self.parent.attrs.values():
                 if isinstance(attr, ColumnProperty):
                     if attr.columns[0].name == column.name:
                         return attr
 
     def init(self):
         def convert_strings(column):
-            if isinstance(column, six.string_types):
+            if isinstance(column, str):
                 return self.parent.columns[column]
             return column
 
@@ -143,7 +147,7 @@ class GenericRelationshipProperty(MapperProperty):
             self._parententity = parentmapper
 
         def __eq__(self, other):
-            discriminator = six.text_type(type(other).__name__)
+            discriminator = type(other).__name__
             q = self.property._discriminator_col == discriminator
             other_id = identity(other)
             for index, id in enumerate(self.property._id_cols):
@@ -157,9 +161,9 @@ class GenericRelationshipProperty(MapperProperty):
             mapper = sa.inspect(other)
             # Iterate through the weak sequence in order to get the actual
             # mappers
-            class_names = [six.text_type(other.__name__)]
+            class_names = [other.__name__]
             class_names.extend([
-                six.text_type(submapper.class_.__name__)
+                submapper.class_.__name__
                 for submapper in mapper._inheriting_mappers
             ])
 
