@@ -1,4 +1,3 @@
-import six
 import sqlalchemy as sa
 from sqlalchemy import types
 
@@ -27,7 +26,7 @@ class ScalarListType(types.TypeDecorator):
 
 
         user = User()
-        user.hobbies = [u'football', u'ice_hockey']
+        user.hobbies = ['football', 'ice_hockey']
         session.commit()
 
 
@@ -69,15 +68,15 @@ class ScalarListType(types.TypeDecorator):
 
     cache_ok = True
 
-    def __init__(self, coerce_func=six.text_type, separator=u','):
-        self.separator = six.text_type(separator)
+    def __init__(self, coerce_func=str, separator=','):
+        self.separator = str(separator)
         self.coerce_func = coerce_func
 
     def process_bind_param(self, value, dialect):
         # Convert list of values to unicode separator-separated list
-        # Example: [1, 2, 3, 4] -> u'1, 2, 3, 4'
+        # Example: [1, 2, 3, 4] -> '1, 2, 3, 4'
         if value is not None:
-            if any(self.separator in six.text_type(item) for item in value):
+            if any(self.separator in str(item) for item in value):
                 raise ScalarListException(
                     "List values can't contain string '%s' (its being used as "
                     "separator. If you wish for scalar list values to contain "
@@ -85,12 +84,12 @@ class ScalarListType(types.TypeDecorator):
                     % self.separator
                 )
             return self.separator.join(
-                map(six.text_type, value)
+                map(str, value)
             )
 
     def process_result_value(self, value, dialect):
         if value is not None:
-            if value == u'':
+            if value == '':
                 return []
             # coerce each value
             return list(map(
