@@ -34,13 +34,13 @@ def init_models(Thread, Comment):
     pass
 
 
-class TestAggregateValueGenerationWithBackrefs(object):
+class TestAggregateValueGenerationWithBackrefs:
 
     def test_assigns_aggregates_on_insert(self, session, Thread, Comment):
         thread = Thread()
-        thread.name = u'some article name'
+        thread.name = 'some article name'
         session.add(thread)
-        comment = Comment(content=u'Some content', thread=thread)
+        comment = Comment(content='Some content', thread=thread)
         session.add(comment)
         session.commit()
         session.refresh(thread)
@@ -53,10 +53,10 @@ class TestAggregateValueGenerationWithBackrefs(object):
         Comment
     ):
         thread = Thread()
-        thread.name = u'some article name'
+        thread.name = 'some article name'
         session.add(thread)
         session.commit()
-        comment = Comment(content=u'Some content', thread=thread)
+        comment = Comment(content='Some content', thread=thread)
         session.add(comment)
         session.commit()
         session.refresh(thread)
@@ -64,10 +64,10 @@ class TestAggregateValueGenerationWithBackrefs(object):
 
     def test_assigns_aggregates_on_delete(self, session, Thread, Comment):
         thread = Thread()
-        thread.name = u'some article name'
+        thread.name = 'some article name'
         session.add(thread)
         session.commit()
-        comment = Comment(content=u'Some content', thread=thread)
+        comment = Comment(content='Some content', thread=thread)
         session.add(comment)
         session.commit()
         session.delete(comment)
