@@ -1,14 +1,18 @@
 import pytest
 import sqlalchemy as sa
-from sqlalchemy.ext.declarative import declarative_base
+import sqlalchemy.orm
 
 from sqlalchemy_utils import cast_if
-from sqlalchemy_utils.compat import get_scalar_subquery
+from sqlalchemy_utils.compat import (
+    _declarative_base,
+    _select_args,
+    get_scalar_subquery
+)
 
 
 @pytest.fixture(scope='class')
 def base():
-    return declarative_base()
+    return _declarative_base()
 
 
 @pytest.fixture(scope='class')
@@ -22,7 +26,7 @@ def article_cls(base):
     return Article
 
 
-class TestCastIf(object):
+class TestCastIf:
     def test_column(self, article_cls):
         expr = article_cls.__table__.c.name
         assert cast_if(expr, sa.String) is expr
@@ -40,7 +44,7 @@ class TestCastIf(object):
         assert cast_if(expr, sa.String) is expr
 
     def test_scalar_selectable(self, article_cls):
-        expr = get_scalar_subquery(sa.select([article_cls.id]))
+        expr = get_scalar_subquery(sa.select(*_select_args(article_cls.id)))
         assert cast_if(expr, sa.Integer) is expr
 
     def test_scalar(self):
