@@ -4,6 +4,7 @@ import pytest
 import sqlalchemy as sa
 
 from sqlalchemy_utils import DateRangeType
+from sqlalchemy_utils.compat import _select_args
 
 intervals = None
 inf = 0
@@ -82,6 +83,12 @@ class DateRangeTestCase:
         assert booking.during.lower == datetime(2015, 1, 1).date()
         assert booking.during.upper == datetime(2015, 1, 1).date()
 
+    def test_compilation(self, session, Booking):
+        query = sa.select(*_select_args(Booking.during))
+
+        # the type should be cacheable and not throw exception
+        session.execute(query)
+
 
 @pytest.mark.usefixtures('postgresql_dsn')
 class TestDateRangeOnPostgres(DateRangeTestCase):
