@@ -1,10 +1,9 @@
-from __future__ import unicode_literals
-
 from datetime import date
 
 import pytest
 import sqlalchemy as sa
 
+from sqlalchemy_utils.compat import _select_args
 from sqlalchemy_utils.types.enriched_datetime import (
     enriched_date_type,
     pendulum_date
@@ -30,7 +29,7 @@ def init_models(User):
 
 
 @pytest.mark.skipif('pendulum_date.pendulum is None')
-class TestPendulumDateType(object):
+class TestPendulumDateType:
     def test_parameter_processing(self, session, User):
         user = User(
             birthday=pendulum_date.pendulum.date(1995, 7, 11)
@@ -63,11 +62,11 @@ class TestPendulumDateType(object):
         assert user.birthday == time.date()
 
     def test_literal_param(self, session, User):
-        clause = User.birthday > '2015-01-01'
+        clause = User.birthday > date(2015, 1, 1)
         compiled = str(clause.compile(compile_kwargs={"literal_binds": True}))
         assert compiled == "users.birthday > '2015-01-01'"
 
     def test_compilation(self, User, session):
-        query = sa.select([User.birthday])
+        query = sa.select(*_select_args(User.birthday))
         # the type should be cacheable and not throw exception
         session.execute(query)
