@@ -1,6 +1,7 @@
 import pytest
 import sqlalchemy as sa
 
+from sqlalchemy_utils.compat import _select_args
 from sqlalchemy_utils.types import url
 
 
@@ -22,10 +23,10 @@ def init_models(User):
 
 
 @pytest.mark.skipif('url.furl is None')
-class TestURLType(object):
+class TestURLType:
     def test_color_parameter_processing(self, session, User):
         user = User(
-            website=url.furl(u'www.example.com')
+            website=url.furl('www.example.com')
         )
 
         session.add(user)
@@ -35,11 +36,11 @@ class TestURLType(object):
         assert isinstance(user.website, url.furl)
 
     def test_scalar_attributes_get_coerced_to_objects(self, User):
-        user = User(website=u'www.example.com')
+        user = User(website='www.example.com')
 
         assert isinstance(user.website, url.furl)
 
     def test_compilation(self, User, session):
-        query = sa.select([User.website])
+        query = sa.select(*_select_args(User.website))
         # the type should be cacheable and not throw exception
         session.execute(query)
